@@ -328,7 +328,7 @@ if(corpus.exists == FALSE) {
                          corpus.dir = primary.corpus.dir,
                          encoding = encoding,
                          markup.type = corpus.format,
-                         language = corpus.lang,
+                         corpus.lang = corpus.lang,
                          splitting.rule = splitting.rule,
                          preserve.case = preserve.case,
                          sample.size = sample.size,
@@ -342,7 +342,7 @@ if(corpus.exists == FALSE) {
                          corpus.dir = secondary.corpus.dir,
                          encoding = encoding,
                          markup.type = corpus.format,
-                         language = corpus.lang,
+                         corpus.lang = corpus.lang,
                          splitting.rule = splitting.rule,
                          preserve.case = preserve.case,
                          sample.size = sample.size,
@@ -817,7 +817,7 @@ filenames.test.set = list.files(test.corpus.dir)
                          corpus.dir = test.corpus.dir,
                          encoding = encoding,
                          markup.type = corpus.format,
-                         language = corpus.lang,
+                         corpus.lang = corpus.lang,
                          splitting.rule = splitting.rule,
                          preserve.case = preserve.case,
                          sample.size = sample.size,
