@@ -183,7 +183,7 @@ custom.graph.filename = variables$custom.graph.filename
 # If no language was chosen (or if a desired language is not supported, or if
 # there was a spelling mistake), then the variable will be set to "English".
 
-pronouns = stylo.pronouns(language = corpus.lang)
+pronouns = stylo.pronouns(corpus.lang = corpus.lang)
 
 
 # Since it it not so easy to perform, say, 17.9 iterations, or analyze
@@ -616,7 +616,7 @@ if(corpus.exists == FALSE) {
                          corpus.dir = corpus.dir,
                          encoding = encoding,
                          markup.type = corpus.format,
-                         language = corpus.lang,
+                         corpus.lang = corpus.lang,
                          splitting.rule = splitting.rule,
                          sample.size = sample.size,
                          sampling = sampling,
